import React, { useRef, useState, useEffect } from 'react';
import { useDisclosure, useDimensions, Popover, forwardRef, useMergeRefs, PopoverContent, Input, PopoverAnchor, Text, Button } from '@chakra-ui/react';
import { isEmpty, isArray, runIfFn, dataAttr } from '@chakra-ui/utils';
import { createContext } from '@chakra-ui/react-utils';
import { useDayzed } from 'dayzed';
import { format, isAfter, isBefore, isFirstDayOfMonth, sub, isLastDayOfMonth, add, isSameDay, isDate, getDaysInMonth, setDate } from 'date-fns';
import { IconButton } from '@chakra-ui/button';
import { FiChevronLeft, FiChevronsLeft, FiChevronRight, FiChevronsRight } from 'react-icons/fi';
import { chakra } from '@chakra-ui/system';
import defaultLocale from 'date-fns/esm/locale/en-US';
import { Text as Text$1 } from '@chakra-ui/layout';

var _createContext = /*#__PURE__*/createContext({
  name: "DateTimePickerContext",
  errorMessage: "useDateTimePickerContext: `context` is undefined. Seems you forgot to wrap all date-time-picker components within `<DateTimePicker />`"
}),
    DateTimePickerProvider = _createContext[0],
    useDateTimePickerContext = _createContext[1];

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectDestructuringEmpty(obj) {
  if (obj == null) throw new TypeError("Cannot destructure undefined");
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var getDataValue = function getDataValue(date) {
  return format(date, DATE_FORMAT);
};
var handleOutsideMonths = function handleOutsideMonths(date) {
  //handle outside months
  if (isFirstDayOfMonth(date)) {
    var previousDate = sub(date, {
      days: 1
    });
    return previousDate;
  }

  if (isLastDayOfMonth(date)) {
    var nextDate = add(date, {
      days: 1
    });
    return nextDate;
  }

  return undefined;
};
var compactDate = function compactDate(dates) {
  var dateArray = dates;
  var startDate = dateArray && dateArray[0];
  var endtDate = dateArray && dateArray[1];
  return [startDate, endtDate];
};
var sortDatesAsc = function sortDatesAsc(dates) {
  return dates.sort(function (a, b) {
    return isAfter(a, b) ? 1 : isBefore(a, b) ? -1 : 0;
  });
};

var useRangeDateProps = function useRangeDateProps(isRange, selected) {
  var _React$useState = React.useState(),
      hoveredDate = _React$useState[0],
      setHoveredDate = _React$useState[1];

  var isWithinHover = function isWithinHover(date) {
    var startDate = selected[0]; // It's not within hovered if two dates have been selected

    if (selected.length === 2) {
      return false;
    }

    var _sortDatesAsc = sortDatesAsc([startDate, hoveredDate]),
        firstDate = _sortDatesAsc[0],
        secondDate = _sortDatesAsc[1]; // Not in hovered range if one date hasn't been selected and not hovering on a second date


    if (!firstDate || !secondDate) {
      return false;
    }

    return (isBefore(firstDate, date) || isSameDay(firstDate, date)) && (isAfter(secondDate, date) || isSameDay(secondDate, date)) //   firstDate.getTime() <= date.getTime() &&
    //   secondDate.getTime() >= date.getTime()
    ;
  };

  var isWithinSelect = function isWithinSelect(date) {
    if (isEmpty(selected)) {
      return false;
    }

    var startDate = selected[0],
        endDate = selected[1];

    if (isSameDay(startDate, date) || isSameDay(endDate, date)) {
      return true;
    }

    return (startDate == null ? void 0 : startDate.getTime()) <= date.getTime() && (endDate == null ? void 0 : endDate.getTime()) >= date.getTime();
  };

  var getRangeHoverStyles = function getRangeHoverStyles(_dateObj) {
    var hoverObj = {};
    return hoverObj;
  };

  var getRangeSelectStyles = function getRangeSelectStyles(_dateObj) {
    var selectObj = {};
    return selectObj;
  };

  var getRangeStyles = function getRangeStyles(dateObj, props) {
    if (!isRange || !selected) return {};
    var _rangeHovered = props._rangeHovered,
        _rangeSelected = props._rangeSelected;
    var rangeHoverStyles = getRangeHoverStyles();
    var rangeSelectStyles = getRangeSelectStyles();
    return {
      "&[data-withinhover]": _rangeHovered || rangeHoverStyles,
      "&[data-withinselect]": _rangeSelected || rangeSelectStyles
    };
  };

  var getHoverEvents = function getHoverEvents(date) {
    return {
      onMouseEnter: function onMouseEnter() {
        return setHoveredDate(date);
      },
      onMouseLeave: function onMouseLeave() {
        return setHoveredDate(undefined);
      }
    };
  };

  return {
    getRangeStyles: getRangeStyles,
    getHoverEvents: getHoverEvents,
    isWithinHover: isWithinHover,
    isWithinSelect: isWithinSelect
  };
};

var _excluded = ["closeOnBlur", "defaultIsOpen", "isDisabled", "isOpen", "isRange", "onChange", "onClose", "onOpen", "onStartDateChange", "onEndDateChange", "openOnFocus", "selected"],
    _excluded2 = ["onBlur", "onFocus"];
/**
 * useDateTimepicker is a hook that provides all the state and focus management logic
 * for the component. It is consumed by the `DatePicker` component
 *
 */

function useDateTimePicker(dateTimePickerProps) {
  var _dateTimePickerProps$ = dateTimePickerProps.closeOnBlur,
      closeOnBlur = _dateTimePickerProps$ === void 0 ? true : _dateTimePickerProps$,
      defaultIsOpen = dateTimePickerProps.defaultIsOpen,
      isDisabled = dateTimePickerProps.isDisabled,
      isOpenProp = dateTimePickerProps.isOpen,
      isRange = dateTimePickerProps.isRange,
      onChange = dateTimePickerProps.onChange,
      onCloseProp = dateTimePickerProps.onClose,
      onOpenProp = dateTimePickerProps.onOpen,
      onStartDateChange = dateTimePickerProps.onStartDateChange,
      onEndDateChange = dateTimePickerProps.onEndDateChange,
      openOnFocus = dateTimePickerProps.openOnFocus,
      selected = dateTimePickerProps.selected,
      restPickerProps = _objectWithoutPropertiesLoose(dateTimePickerProps, _excluded);

  var _useDisclosure = useDisclosure({
    defaultIsOpen: defaultIsOpen,
    isOpen: isOpenProp,
    onClose: onCloseProp,
    onOpen: onOpenProp
  }),
      isOpen = _useDisclosure.isOpen,
      onClose = _useDisclosure.onClose,
      onOpen = _useDisclosure.onOpen;

  var inputRef = useRef(null);
  var listRef = useRef(null);

  var isValidDate = function isValidDate(date) {
    return isDate(date);
  };

  var getDefaultDate = function getDefaultDate() {
    if (isValidDate(selected)) return selected;
    if (isArray(selected) && isValidDate(selected[0])) return selected[0];
    return new Date();
  };

  var defaultDate = getDefaultDate();

  var _useState = useState(defaultDate),
      date = _useState[0],
      setDate$1 = _useState[1];

  var _useState2 = useState(),
      offset = _useState2[0],
      setOffset = _useState2[1];

  var _useState3 = useState(""),
      input = _useState3[0],
      setInput = _useState3[1];

  var _compactDate = compactDate(selected),
      startDate = _compactDate[0],
      endDate = _compactDate[1];

  var setToDate = function setToDate(date) {
    setDate$1(date);
    setOffset(0);
  };

  useEffect(function () {
    console.log(isValidDate(new Date())); // if (isValidDate(selected)) setToDate(selected);
  }, []);

  var dateIsValid = function dateIsValid(stringDate) {
    var yearConstruct = new Date(stringDate).getFullYear();
    return !isNaN(yearConstruct);
  };

  var updateSingleDate = function updateSingleDate(newDate) {
    if (dateIsValid(newDate)) {
      runIfFn(onChange, new Date(newDate));
    }
  };

  var updateRangeDate = function updateRangeDate(dateObj) {
    // Set start date
    if (startDate && endDate) {
      runIfFn(onStartDateChange, dateObj.date);
      onChange([dateObj.date]);
      return;
    } // Set second date selected and correct ordering, as user may select dates
    // in reverse order


    if (startDate && !endDate && !isSameDay(dateObj.date, startDate)) {
      var _sortDatesAsc = sortDatesAsc([startDate, dateObj.date]),
          newStart = _sortDatesAsc[0],
          newEnd = _sortDatesAsc[1];

      runIfFn(onStartDateChange, newStart);
      runIfFn(onEndDateChange, newEnd);
      onChange([newStart, newEnd]);
      return;
    } // Otherwise, reset dates


    runIfFn(onStartDateChange, dateObj.date);
    runIfFn(onEndDateChange, undefined);
    onChange([dateObj.date]);
  };

  var onDateSelected = function onDateSelected(dateObj) {
    if (!dateObj.selectable) {
      return;
    }

    if (isRange) {
      updateRangeDate(dateObj);
    } else {
      updateSingleDate(dateObj.date);
    }
  };

  var dayzedProps = useDayzed(_extends({
    date: date,
    monthsToDisplay: 1,
    offset: offset,
    onDateSelected: onDateSelected,
    onOffsetChanged: setOffset,
    selected: selected,
    showOutsideDays: true
  }, restPickerProps));
  React.useEffect(function () {
    if (selected) {
      //TODO Watch here for other modes aside single picker
      //! Account for range Here
      var formattedValue = isRange ? null : format(selected, DATE_FORMAT);
      if (formattedValue) setInput(formattedValue);
    }
  }, [selected]);

  var getFirstDayInMonth = function getFirstDayInMonth() {
    var _listRef$current;

    return listRef == null ? void 0 : (_listRef$current = listRef.current) == null ? void 0 : _listRef$current.querySelector("[data-enabled]");
  };

  var getDateButton = function getDateButton(dataValue) {
    var _listRef$current2;

    return listRef == null ? void 0 : (_listRef$current2 = listRef.current) == null ? void 0 : _listRef$current2.querySelector("[data-value='" + dataValue + "']");
  };

  var rangeDateProps = useRangeDateProps(isRange, selected);

  var getInputProps = function getInputProps(props) {
    var _onBlur = props.onBlur,
        _onFocus = props.onFocus,
        rest = _objectWithoutPropertiesLoose(props, _excluded2);

    var onChangeInput = function onChangeInput(e) {
      var inputValue = e.target.value;

      if (dateIsValid(inputValue)) {
        // TODO

        /** We'll have two inputs when it's a range, and dynamically pass different props for those inputs, so input 1 should be updating start-date and 2: end-date */
        //! Account for range Here
        // updateDate(inputValue);
        setDate$1(new Date(inputValue));
      }

      setInput(inputValue);
    };

    return _extends({
      onFocus: function onFocus(e) {
        runIfFn(_onFocus, e);
        if (openOnFocus && !isDisabled) onOpen();
      },
      onBlur: function onBlur(e) {
        var _listRef$current3;

        runIfFn(_onBlur, e);
        var listIsFocused = e.relatedTarget === (listRef == null ? void 0 : listRef.current);
        var listContainsEvent = (_listRef$current3 = listRef.current) == null ? void 0 : _listRef$current3.contains(e.relatedTarget);
        if (!listIsFocused && !listContainsEvent && closeOnBlur) onClose();
      },
      value: input,
      onChange: onChangeInput
    }, rest);
  };

  var inputDimensions = useDimensions(inputRef, true); // const { getDateButton } = useDateButton();

  var getListProps = function getListProps() {
    var width = inputDimensions == null ? void 0 : inputDimensions.marginBox.width;
    return {
      width: width,
      onFocus: function onFocus(e) {
        var contentIsTarget = e.target === e.currentTarget;

        if (contentIsTarget) {
          //focus the selected date, if none then today's date
          var dateValueData = getDataValue((isRange ? startDate : selected) || new Date());
          var dateToFocus = getDateButton(dateValueData);
          if (dateToFocus) dateToFocus.focus();
        }
      }
    };
  };

  var getWeekDateProps = function getWeekDateProps() {
    var findNextDate = function findNextDate(currentDate, direction) {
      var func = DATE_ARROW_METHODS[direction].func;
      var daysInMonth = getDaysInMonth(currentDate); //Add 1 day to account for 0 indexing

      var daysInMonthArray = Array.from({
        length: daysInMonth
      }, function (_v, i) {
        return i + 1;
      });
      var nextDays = func(daysInMonthArray, currentDate.getDate());
      var nextValidDateButton = nextDays.reduce(function (acc, day) {
        var dateFromDay = setDate(currentDate, day);
        var dataValue = getDataValue(dateFromDay);
        var dateButton = getDateButton(dataValue);

        if (((dateButton == null ? void 0 : dateButton.dataset["enabled"]) === "" || // Don't move focus when navigating up or down and the next date is disabled
        ["ArrowUp", "ArrowDown"].includes(direction)) && !acc) {
          acc = dateButton;
        }

        return acc;
      }, undefined);
      return nextValidDateButton;
    };

    return {
      findNextDate: findNextDate,
      getDateButton: getDateButton,
      rangeDateProps: rangeDateProps
    };
  };

  return {
    dateTimePickerProps: dateTimePickerProps,
    dayzedProps: dayzedProps,
    getFirstDayInMonth: getFirstDayInMonth,
    getInputProps: getInputProps,
    getListProps: getListProps,
    getWeekDateProps: getWeekDateProps,
    inputRef: inputRef,
    isOpen: isOpen,
    listRef: listRef,
    offset: offset,
    onClose: onClose,
    onOpen: onOpen,
    date: date,
    setDate: setDate$1,
    setOffset: setOffset,
    setToDate: setToDate
  };
}

var DateTimePicker = function DateTimePicker(props) {
  var context = useDateTimePicker(props);
  var isOpen = context.isOpen,
      onClose = context.onClose,
      onOpen = context.onOpen;
  var children = runIfFn(props.children, context);
  var _props$placement = props.placement,
      placement = _props$placement === void 0 ? "bottom" : _props$placement;
  return React.createElement(DateTimePickerProvider, {
    value: context
  }, React.createElement(Popover, {
    isLazy: true,
    isOpen: isOpen,
    onClose: onClose,
    onOpen: onOpen,
    placement: placement,
    closeOnBlur: true
  }, children));
};

var _excluded$1 = ["children"];
var DateTimePickerContent = /*#__PURE__*/forwardRef(function (props, forwardedRef) {
  var context = useDateTimePickerContext();
  var listRef = context.listRef,
      getListProps = context.getListProps;

  var children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, _excluded$1);

  var ref = useMergeRefs(forwardedRef, listRef);
  var listProps = getListProps();
  var contentChildren = runIfFn(children, context);
  return React.createElement(PopoverContent, Object.assign({
    ref: ref
  }, baseStyles, listProps, restProps), contentChildren);
});
DateTimePickerContent.displayName = "DateTimePickerContent";
var baseStyles = {
  mt: "2",
  py: "4",
  bg: "gray.700",
  rounded: "md",
  border: "none",
  shadow: "base",
  zIndex: "popover",
  textAlign: "center",
  _light: {
    bg: "#ffffff"
  },
  _focus: {
    boxShadow: "none"
  }
};

var _excluded$2 = ["children"];
var DateTimePickerTrigger = function DateTimePickerTrigger(props) {
  var context = useDateTimePickerContext();
  var inputRef = context.inputRef,
      getInputProps = context.getInputProps;
  var ref = useMergeRefs(inputRef);

  var children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, _excluded$2);

  var inputProps = getInputProps(restProps);
  var customTrigger = runIfFn(children, context);
  var inputTrigger = React.createElement(Input, Object.assign({}, inputProps, {
    ref: ref
  }));
  var trigger = children ? customTrigger : inputTrigger;
  return React.createElement(PopoverAnchor, null, trigger);
};
DateTimePickerTrigger.displayName = "Input";
DateTimePickerTrigger.id = "Input";

function capitalizeFirstLetter(string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}
var getDefaultArrowProps = function getDefaultArrowProps(_ref) {
  var direction = _ref.direction,
      _ref$arrowType = _ref.arrowType,
      arrowType = _ref$arrowType === void 0 ? "month" : _ref$arrowType;
  return {
    "aria-label": capitalizeFirstLetter(direction) + " " + (arrowType || "month"),
    variant: "ghost",
    size: "sm",
    icon: icons[direction][arrowType || "month"]
  };
};
var icons = {
  previous: {
    month: /*#__PURE__*/React.createElement(FiChevronLeft, null),
    year: /*#__PURE__*/React.createElement(FiChevronsLeft, null)
  },
  next: {
    month: /*#__PURE__*/React.createElement(FiChevronRight, null),
    year: /*#__PURE__*/React.createElement(FiChevronsRight, null)
  }
};

var _excluded$3 = ["as", "direction"],
    _excluded2$1 = ["arrowType"];
var ArrowButton = function ArrowButton(props) {
  var As = props.as,
      direction = props.direction,
      restProps = _objectWithoutPropertiesLoose(props, _excluded$3);

  var buttonProps = useMonthArrowButton(direction, restProps);
  var defaultArrowProps = getDefaultArrowProps(props);
  var defaultButton = React.createElement(IconButton, Object.assign({}, defaultArrowProps, buttonProps));
  var Button = As ? React.createElement(As, Object.assign({}, buttonProps)) : defaultButton;
  return Button;
};
var useMonthArrowButton = function useMonthArrowButton(direction, props) {
  var _useDateTimePickerCon = useDateTimePickerContext(),
      dayzedProps = _useDateTimePickerCon.dayzedProps;

  var calendars = dayzedProps.calendars,
      getBackProps = dayzedProps.getBackProps,
      getForwardProps = dayzedProps.getForwardProps;

  var _props$arrowType = props.arrowType,
      arrowType = _props$arrowType === void 0 ? "month" : _props$arrowType,
      restProps = _objectWithoutPropertiesLoose(props, _excluded2$1);

  var directionProps = {
    previous: getBackProps,
    next: getForwardProps
  };
  var buttonProps = directionProps[direction](_extends({
    calendars: calendars,
    offset: ARROW_BUTTON_OFFSET[arrowType]
  }, restProps));
  return buttonProps;
};
var BackButton = function BackButton(props) {
  return React.createElement(ArrowButton, Object.assign({
    direction: "previous"
  }, props));
};
var NextButton = function NextButton(props) {
  return React.createElement(ArrowButton, Object.assign({
    direction: "next"
  }, props));
};

var _excluded$4 = ["format", "calendar"];
function CalendarMonth(props) {
  var _props$format = props.format,
      dateFormat = _props$format === void 0 ? "short" : _props$format,
      calendar = props.calendar,
      restProps = _objectWithoutPropertiesLoose(props, _excluded$4);

  var date = new Date();
  date.setMonth(calendar.month);
  var monthFormat = {
    "short": "MMM",
    "long": "MMMM"
  };
  var month = format(date, monthFormat[dateFormat]);
  return React.createElement(Text, Object.assign({}, restProps), month);
}

var _excluded$5 = ["format", "calendar"];
function CalendarYear(props) {
  var _props$format = props.format,
      dateFormat = _props$format === void 0 ? "long" : _props$format,
      calendar = props.calendar,
      restProps = _objectWithoutPropertiesLoose(props, _excluded$5);

  var date = new Date();
  date.setFullYear(calendar.year);
  var yearFormat = {
    "short": "yy",
    "long": "yyyy"
  };
  var year = format(date, yearFormat[dateFormat]);
  return React.createElement(Text, Object.assign({}, restProps), year);
}

var useWeekNames = function useWeekNames(format) {
  var _useDateTimePickerCon = useDateTimePickerContext(),
      dateTimePickerProps = _useDateTimePickerCon.dateTimePickerProps;

  var DEFAULT_FORMAT = "narrow";
  var _dateTimePickerProps$ = dateTimePickerProps.locale,
      locale = _dateTimePickerProps$ === void 0 ? defaultLocale : _dateTimePickerProps$,
      _dateTimePickerProps$2 = dateTimePickerProps.firstDayOfWeek,
      firstDayOfWeek = _dateTimePickerProps$2 === void 0 ? 0 : _dateTimePickerProps$2;
  var weekdays = Array.from({
    length: 7
  }, function (_, i) {
    var _locale$localize;

    return locale == null ? void 0 : (_locale$localize = locale.localize) == null ? void 0 : _locale$localize.day(i, {
      width: format || DEFAULT_FORMAT
    });
  });
  var reArrangedWeekdays = weekdays.map(function (_, i) {
    return weekdays[(i + firstDayOfWeek) % 7];
  });
  return reArrangedWeekdays;
};

var _excluded$6 = ["children", "format"];
var WeekNames = function WeekNames(props) {
  var children = props.children,
      format = props.format,
      restProps = _objectWithoutPropertiesLoose(props, _excluded$6);

  var weekdays = useWeekNames(format);
  var customWeekNames = runIfFn(children, {
    weekdays: weekdays
  });
  var defaultWeekNames = React.createElement(WeekDays, {
    format: format
  });
  var weekNames = children ? customWeekNames : defaultWeekNames;
  return React.createElement(chakra.div, Object.assign({}, restProps), weekNames);
};

var WeekDays = function WeekDays(props) {
  var format = props.format;
  var weekdays = useWeekNames(format);
  return React.createElement(React.Fragment, null, weekdays.map(function (weekday, i) {
    return React.createElement(WeekDay, {
      key: weekday + "-" + i
    }, weekday);
  }));
};

var WeekDay = function WeekDay(props) {
  return React.createElement(Text$1, Object.assign({
    display: "inline-block",
    sx: {
      w: "calc(100% / 7)"
    }
  }, props));
};

var _excluded$7 = ["dateObj", "_today", "_rangeHovered", "_rangeSelected"];
var WeekDate = function WeekDate(props) {
  var dateObj = props.dateObj,
      _today = props._today,
      restProps = _objectWithoutPropertiesLoose(props, _excluded$7);

  var _useDateTimePickerCon = useDateTimePickerContext(),
      dayzedProps = _useDateTimePickerCon.dayzedProps,
      dateTimePickerProps = _useDateTimePickerCon.dateTimePickerProps,
      setDate = _useDateTimePickerCon.setDate,
      calendarDate = _useDateTimePickerCon.date,
      getFirstDayInMonth = _useDateTimePickerCon.getFirstDayInMonth,
      getWeekDateProps = _useDateTimePickerCon.getWeekDateProps;

  var disabledDates = dateTimePickerProps.disabledDates,
      disableOutsideMonths = dateTimePickerProps.disableOutsideMonths,
      selected = dateTimePickerProps.selected;
  var getDateProps = dayzedProps.getDateProps;

  var _getWeekDateProps = getWeekDateProps(),
      findNextDate = _getWeekDateProps.findNextDate,
      getDateButton = _getWeekDateProps.getDateButton,
      rangeDateProps = _getWeekDateProps.rangeDateProps;

  var getHoverEvents = rangeDateProps.getHoverEvents,
      getRangeStyles = rangeDateProps.getRangeStyles,
      isWithinHover = rangeDateProps.isWithinHover,
      isWithinSelect = rangeDateProps.isWithinSelect;
  if (!dateObj) return null;
  React.useEffect(function () {
    var dateValue = getDataValue(calendarDate);
    var dateButton = getDateButton(dateValue);
    if (dateButton) dateButton.focus();else {
      // Focus the first day whwenever we navigate the months
      var firstDay = getFirstDayInMonth();
      firstDay.focus();
    }
  }, [calendarDate]);
  var date = dateObj.date,
      isSelected = dateObj.selected,
      selectable = dateObj.selectable,
      today = dateObj.today,
      prevMonth = dateObj.prevMonth,
      nextMonth = dateObj.nextMonth;
  var isOutsideMonth = prevMonth || nextMonth;
  var disableAsOutsideMonths = isOutsideMonth && disableOutsideMonths;
  var isAmongDisabledDates = disabledDates == null ? void 0 : disabledDates.some(function (d) {
    return isSameDay(d, date);
  });
  var isDisabled = !selectable || disableAsOutsideMonths || isAmongDisabledDates || props.isDisabled;
  var dataValue = getDataValue(date);

  var onKeyDown = function onKeyDown(e) {
    if (ARROW_KEYS.includes(e.key)) {
      var nextFocusDate = findNextDate(date, e.key); //handle outside months

      if (["ArrowRight", "ArrowLeft"].includes(e.key) && !nextFocusDate) {
        var outsideMonthDate = handleOutsideMonths(date);
        if (outsideMonthDate) setDate(outsideMonthDate);
      }

      nextFocusDate == null ? void 0 : nextFocusDate.focus();
      e.preventDefault();
    }
  };

  var dataset = {
    "data-enabled": dataAttr(!isDisabled),
    "data-selected": dataAttr(isSelected),
    "data-today": dataAttr(today),
    "data-value": dataValue,
    "data-withinhover": dataAttr(selected && isWithinHover(dateObj.date)),
    "data-withinselect": dataAttr(selected && isWithinSelect(dateObj.date))
  };
  var rangeHoverEvents = getHoverEvents(date);
  var rangeStyles = getRangeStyles(dateObj, props);
  return React.createElement(Button, Object.assign({}, getDateProps({
    dateObj: dateObj,
    disabled: isDisabled
  }), dataset, {
    _disabled: defaultDisabledStyles,
    _selected: defaultSelectedStyles,
    __css: _extends({
      "&[data-today]": _today || defaultTodayStyles
    }, rangeStyles, defaultRootStyles),
    onKeyDown: onKeyDown
  }, rangeHoverEvents, restProps), date.getDate());
};
var defaultDisabledStyles = {
  color: "gray.300",
  cursor: "not-allowed",
  _dark: {
    color: "gray.600"
  }
};
var defaultSelectedStyles = {
  bg: "blue.400",
  color: "white",
  shadow: "lg"
};
var defaultTodayStyles = {
  bg: "blue.50",
  color: "blue.500"
};
var defaultRootStyles = {
  rounded: "full",
  boxSize: 8,
  justifySelf: "center",
  variant: "ghost",
  borderWidth: 1,
  borderColor: "transparent"
};

function YearPicker(props) {
  _objectDestructuringEmpty(props);

  return React.createElement("div", null, "Year Picker");
}

var DATE_ARROW_METHODS = {
  ArrowUp: {
    func: function func(monthDaysArray, currentDate) {
      return monthDaysArray.filter(function (day) {
        return day < currentDate - 6;
      }).reverse();
    }
  },
  ArrowRight: {
    func: function func(monthDaysArray, currentDate) {
      return monthDaysArray.filter(function (day) {
        return day > currentDate;
      });
    }
  },
  ArrowDown: {
    func: function func(monthDaysArray, currentDate) {
      return monthDaysArray.filter(function (day) {
        return day > currentDate + 6;
      });
    }
  },
  ArrowLeft: {
    func: function func(monthDaysArray, currentDate) {
      return monthDaysArray.filter(function (day) {
        return day < currentDate;
      }).reverse();
    }
  }
};
var ARROW_KEYS = ["ArrowUp", "ArrowRight", "ArrowDown", "ArrowLeft"];
var DATE_FORMAT = "dd-MM-yyyy";
var ARROW_BUTTON_OFFSET = {
  month: 1,
  year: 12
};

export { ARROW_BUTTON_OFFSET, ARROW_KEYS, ArrowButton, BackButton, CalendarMonth, CalendarYear, DATE_ARROW_METHODS, DATE_FORMAT, DateTimePicker, DateTimePickerContent, DateTimePickerTrigger, NextButton, WeekDate, WeekDay, WeekNames, YearPicker, useDateTimePicker, useMonthArrowButton };
//# sourceMappingURL=choc-datetimepicker.esm.js.map
